@@ -1,5 +1,4 @@
 from pants.engine.rules import collect_rules
-
 from pants_backend_kustomize import codegen
 from pants_backend_kustomize import target_types as targets
 from pants_backend_kustomize.util_rules import prepare_context
@@ -12,4 +11,9 @@ def target_types():
 
 
 def rules():
-    return [*collect_rules(), *targets.rules(), *codegen.rules(), *prepare_context.rules()]
+    return [
+        *collect_rules(),
+        *targets.rules(),
+        *codegen.rules(),
+        *prepare_context.rules(),
+    ]
